@@ -60,8 +60,15 @@ class UglipyJS:
 	#
 	# Returns minified code as String
 	def really_compile(self,source,generate_map):
-		source = unicode(source,self._options['encoding']) if isinstance(source,unicode) or isinstance(source,str) else source.read()
+		if isinstance(source, str):
+			try:
+				source = unicode(source, self._options['encoding'])
+			except:
+				source = source
+		elif hasattr(source, "read"):
+			source = source.read()
 
+		source = source.replace('\\xa0', ' ')
 		source = source.replace('\t',' ')
 
 		js = """var options = %s;
@@ -120,7 +127,7 @@ if (options.generate_map) {
 
 		}
 
-		return self._context.exec_(js % json.dumps(options))
+		return self._context.exec_(js % json.dumps(options)).encode(self._options['encoding'])
 
 	def should_mangle(self):
 		return not not self._options['mangle']
